/**************************************************************************
 *   global.c                                                             *
 *                                                                        *
 *   Copyright (C) 1999 Chris Allegretta                                  *
 *   This program is free software; you can redistribute it and/or modify *
 *   it under the terms of the GNU General Public License as published by *
 *   the Free Software Foundation; either version 1, or (at your option)  *
 *   any later version.                                                   *
 *                                                                        *
 *   This program is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 *   GNU General Public License for more details.                         *
 *                                                                        *
 *   You should have received a copy of the GNU General Public License    *
 *   along with this program; if not, write to the Free Software          *
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
 *                                                                        *
 **************************************************************************/

#include <sys/stat.h>
#include "config.h"
#include "nano.h"

/*
 * Global variables
 */
int center_x = 0, center_y = 0;	/* Center of screen */
WINDOW *edit;			/* The file portion of the editor  */
WINDOW *topwin;			/* Top line of screen */
WINDOW *bottomwin;		/* Bottom buffer */
int file;			/* Actual file pointer */
char *filename;			/* Name of the file */
int modified = 0;		/* Has file been modified? */
struct stat fileinfo;		/* Informatio about the file */
int editwinrows = 0;		/* How many rows long is the edit
				   window? */
int editwineob = 0;		/* Last Line in edit buffer
				   (0 - editwineob) */
filestruct *current;		/* Current buffer pointer */
int current_x = 0, current_y = 0;	/* Current position of X and Y in
					   the editor - relative to edit
					   window (0,0) */
filestruct *fileage = NULL;	/* Our file buffer */
filestruct *edittop = NULL;	/* Pointer to the top of the edit
				   buffer with respect to the
				   file struct */
filestruct *editbot = NULL;	/* Same for the bottom */
filestruct *filebot = NULL;	/* Last node in the file struct */
filestruct *cutbuffer = NULL;	/* A place to store cut text */
filestruct *cutbottom = NULL;	/* Pointer to end of cutbuffer */
int keep_cutbuffer = 0;		/* Clear out the cutbuffer? */

char answer[132] = "";		/* Answer str to many questions */
char last_search[132] = "";	/* Last string we searched for */
char last_replace[132] = "";	/* Last replacement string */
int totlines = 0;		/* Total number of lines in the file */
int totsize = 0;		/* Total number of bytes in the file */
int suspend = 0;		/* Can nano be suspended */
int case_sensitive = 0;		/* Are we doing case sensitive
				   searches */
int placewewant = 0;		/* The collum we'd like the cursor
				   to jump to when we go to the
				   next or previous line */

int statblank = 0;		/* Number of keystrokes left after
				   we call statubar() before we
				   actually blank the statusbar */
int mark_isset = 0;		/* Is the marker currently active */
int no_wrap = 0;		/* Is wrapping turned on? */
int autoindent = 0;		/* Autoindent turned on? */
int samelinewrap = 0;		/* Wrap to the beginning of the next line 
				   instead of starting a new one? */
int constupdate = 0;		/* Do we always show the cursor pos on statusbar? */
int no_help = 0;		/* No help at the bottom of the screen */
int help_mode = 0;		/* Are we in help mode (^G) */
int temp_opt = 0;		/* Editing temp file (pico -t option) */
int view_mode = 0;		/* View (read-only, uh kinda) mode */
int fill = 0;			/* Fill - where to wrap lines, basically */
int use_mouse = 0;		/* Enable mouse events. */

char *hblank;			/* A horizontal blank line */
char *alt_speller;		/* Alternative spell command */

/* More stuff for the marker select */

filestruct *mark_beginbuf;	/* the begin marker buffer */
int mark_beginx;		/* X value in the string to start */
int marked_cut;			/* Is the cutbuffer from a mark */

shortcut main_list[MAIN_LIST_LEN];
shortcut whereis_list[WHEREIS_LIST_LEN];
shortcut replace_list[REPLACE_LIST_LEN];
shortcut goto_list[GOTO_LIST_LEN];
shortcut writefile_list[WRITEFILE_LIST_LEN];

/* Initialize a struct *without* our lovely braces =( */
void sc_init_one(shortcut * s, int key, char *desc, char *help)
{
    s->val = key;
    s->desc = desc;
    s->help = help;
}

void shortcut_init(void)
{
    sc_init_one(&main_list[0], NANO_WRITEOUT_KEY, NANO_WRITEOUT_MSG,
		NANO_WRITEOUT_HELP);
    sc_init_one(&main_list[1], NANO_EXIT_KEY, NANO_EXIT_MSG,
		NANO_EXIT_HELP);
    sc_init_one(&main_list[2], NANO_GOTO_KEY, NANO_GOTO_MSG,
		NANO_GOTO_HELP);
    sc_init_one(&main_list[3], NANO_REPLACE_KEY, NANO_REPLACE_MSG,
		NANO_REPLACE_HELP);
    sc_init_one(&main_list[4], NANO_INSERTFILE_KEY, NANO_INSERTFILE_MSG,
		NANO_INSERTFILE_HELP);
    sc_init_one(&main_list[5], NANO_WHEREIS_KEY, NANO_WHEREIS_MSG,
		NANO_WHEREIS_HELP);
    sc_init_one(&main_list[6], NANO_PREVPAGE_KEY, NANO_PREVPAGE_MSG,
		NANO_PREVPAGE_HELP);
    sc_init_one(&main_list[7], NANO_NEXTPAGE_KEY, NANO_NEXTPAGE_MSG,
		NANO_NEXTPAGE_HELP);
    sc_init_one(&main_list[8], NANO_CUT_KEY, NANO_CUT_MSG, NANO_CUT_HELP);
    sc_init_one(&main_list[9], NANO_UNCUT_KEY, NANO_UNCUT_MSG,
		NANO_UNCUT_HELP);
    sc_init_one(&main_list[10], NANO_CURSORPOS_KEY, NANO_CURSORPOS_MSG,
		NANO_CURSORPOS_HELP);
    sc_init_one(&main_list[11], NANO_SPELL_KEY, NANO_SPELL_MSG,
		NANO_SPELL_HELP);

    sc_init_one(&whereis_list[0], NANO_FIRSTLINE_KEY, NANO_FIRSTLINE_MSG,
		NANO_FIRSTLINE_HELP);
    sc_init_one(&whereis_list[1], NANO_LASTLINE_KEY, NANO_LASTLINE_MSG,
		NANO_LASTLINE_HELP);
    sc_init_one(&whereis_list[2], NANO_CASE_KEY, NANO_CASE_MSG,
		NANO_CASE_HELP);
    sc_init_one(&whereis_list[3], NANO_CANCEL_KEY, NANO_CANCEL_MSG,
		NANO_CANCEL_HELP);

    sc_init_one(&replace_list[0], NANO_FIRSTLINE_KEY, NANO_FIRSTLINE_MSG,
		NANO_FIRSTLINE_HELP);
    sc_init_one(&replace_list[1], NANO_LASTLINE_KEY, NANO_LASTLINE_MSG,
		NANO_LASTLINE_HELP);
    sc_init_one(&replace_list[2], NANO_CASE_KEY, NANO_CASE_MSG,
		NANO_CASE_HELP);
    sc_init_one(&replace_list[3], NANO_CANCEL_KEY, NANO_CANCEL_MSG,
		NANO_CANCEL_HELP);

    sc_init_one(&goto_list[0], NANO_FIRSTLINE_KEY, NANO_FIRSTLINE_MSG,
		NANO_FIRSTLINE_HELP);
    sc_init_one(&goto_list[1], NANO_LASTLINE_KEY, NANO_LASTLINE_MSG,
		NANO_LASTLINE_HELP);
    sc_init_one(&goto_list[2], NANO_CANCEL_KEY, NANO_CANCEL_MSG,
		NANO_CANCEL_HELP);

    sc_init_one(&writefile_list[0], NANO_CANCEL_KEY, NANO_CANCEL_MSG,
		NANO_CANCEL_HELP);

}
